Package: bayprior
Title: Bayesian Prior Elicitation and Diagnostics for Clinical Trials
Version: 0.2.12
Authors@R: 
    person("Ndoh", "Penn", email = "ndohpenn9@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0009-0003-9054-465X"))
Description: A toolkit for constructing, validating, and justifying Bayesian priors
  in clinical trial settings. Implements expert elicitation via quantile
  matching, the roulette method, and moment matching across six distribution
  families, linear and logarithmic expert pooling, prior-data conflict
  diagnostics including the Box p-value, surprise index, information
  divergence, and Mahalanobis distance, sensitivity analyses with tornado
  and influence heatmap plots, sceptical, robust, and power priors, and
  automated prior justification reports. Includes a fully modular 'Shiny'
  application for interactive use.
  Methods based on O'Hagan et al. (2006, ISBN:9780470029886),
  Box (1980) <doi:10.2307/2982063>,
  Oakley and O'Hagan (2010) <https://tonyohagan.co.uk/shelf/>,
  Schmidli et al. (2014) <doi:10.1111/biom.12242>,
  Ibrahim and Chen (2000) <doi:10.1214/ss/1009212673>,
  Spiegelhalter et al. (1994) <doi:10.2307/2983527>.
License: GPL-3
URL: https://github.com/ndohpenngit/bayprior
BugReports: https://github.com/ndohpenngit/bayprior/issues
Depends: R (>= 4.1.0)
Imports: cli (>= 3.6.0), config (>= 0.3.1), dplyr (>= 1.1.0), DT (>=
        0.27), ggplot2 (>= 3.4.0), glue (>= 1.6.2), golem (>= 0.4.1),
        plotly (>= 4.10.1), purrr (>= 1.0.0), rlang (>= 1.2.0), shiny
        (>= 1.7.4), shinycssloaders (>= 1.0.0), shinydashboard (>=
        0.7.2), shinyjs (>= 2.1.0), shinyWidgets (>= 0.7.6), stats
Suggests: htmlwidgets (>= 1.5.4), knitr (>= 1.40), patchwork (>=
        1.1.0), quarto (>= 1.4), rmarkdown (>= 2.20), shinytest2 (>=
        0.3.1), spelling (>= 2.2.0), testthat (>= 3.0.0), vdiffr (>=
        1.0.0), withr (>= 2.5.0)
VignetteBuilder: knitr
Config/Needs/vignettes: knitr, rmarkdown
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.3
SystemRequirements: Quarto CLI (>= 1.5, https://quarto.org)
NeedsCompilation: no
Packaged: 2026-05-29 21:31:16 UTC; ndohpenn
Author: Ndoh Penn [aut, cre] (ORCID: <https://orcid.org/0009-0003-9054-465X>)
Maintainer: Ndoh Penn <ndohpenn9@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-03 13:00:08 UTC
Built: R 4.6.0; ; 2026-06-03 13:10:24 UTC; unix
